
          real*8 BrTXL(38)
          real*8 BrSTLA(41, 38)
          real*8 BrSTLB(41, 38)


          real*8 PrTXL(48)
          real*8 PrSTLA(41, 48)
          real*8 PrSTLB(41, 48)

        
          real*8 BrTXS(42)
          real*8 BrSTSA(41, 42)
          real*8 BrSTSB(41, 42)


      common /ZbpTable/
     *  BrSTLA, BrSTLB,  PrSTLA, 
     *  PrSTLB,  BrSTSA, BrSTSB, BrTXS,
     *  PrTXL, BrTXL

!    *BrTXL, BrSTLA, BrSTLB, BrTXH, BrSTHA, BrSTHB, PrTXL, PrSTLA, 
!    *PrSTLB, PrTXH, PrSTH, BrTXS, BrSTSA, BrSTSB
!     * , MuNTX, MuNdEdx0, 
!     *MuNdEdxt, MuBrTX, MuBrdEdx0, MuBrdEdxt, MuPrTX, MuPrdEdx0, 
!     *MuPrdEdxt, MuNTbl, MuBrTbl, MuPrTbl
!

          
     

  
